.. SymPy documentation master file, created by sphinx-quickstart.py on Sat Mar 22 19:34:32 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SymPy's documentation!
=================================

`SymPy <http://sympy.org>`_ is a Python library for symbolic mathematics.
If you are new to SymPy, start with the Tutorial.

This is the central page for all of SymPy's documentation.


Contents:

.. toctree::
   :maxdepth: 2

   install.rst
   tutorial.rst
   gotchas.rst
   guide.rst
   modules/index.rst
   python-comparisons.rst
   wiki.rst
   outreach.rst
   aboutus.rst

If something cannot be easily accessed from this page, it's a bug (`please
report it`_).

This documentation is maintained with docutils, so you might see some comments in the form #doctest:... . You can safely ignore them.

.. _please report it: http://code.google.com/p/sympy/issues/list
